#!/usr/bin/env scheme-script
;; -*- mode: scheme; coding: utf-8 -*- !#
;; Copyright (c) 2025 Vadym Kochan <vadim4j@gmail.com> 
;; SPDX-License-Identifier: MIT
#!r6rs

(import (rnrs (6))
	(srfi :64 testing)
	(onie info))

(test-begin "write/read onie info")
(let-values ([(outp get-bv) (open-bytevector-output-port)])
  (let ([inf (make-onie-info)])
    (onie-info-product-name-set! inf "prod1")
    (onie-info-part-number-set! inf "part-num1")
    (onie-info-serial-number-set! inf "serial1")
    (onie-info-mac-base-set! inf #vu8(11 22 33 44 55 66))
    (onie-info-manufacture-date-set! inf "08/16/2024 00:00:00")
    (onie-info-device-version-set! inf 1)
    (onie-info-label-revision-set! inf "R01")
    (onie-info-platform-name-set! inf "arm64-accton_xxx-r0")
    (onie-info-onie-version-set! inf "1.1.1")
    (onie-info-num-macs-set! inf 63)
    (onie-info-manufacturer-set! inf "SomeSwitchMfg")
    (onie-info-country-code-set! inf "UA")
    (onie-info-vendor-set! inf "SomeVendor")
    (onie-info-diag-version-set! inf "V1.1.3.243")
    (onie-info-service-tag-set! inf "3001995")
    (onie-info-vendor-extension-set! inf #vu8(1 2 3 4 5 6))
    (write-onie-info inf outp))
  (let ([bytes (get-bv)])
    (call-with-port (open-bytevector-input-port bytes)
      (lambda (port)
        (let ([inf (read-onie-info port)])
	  (test-assert (onie-info-crc-valid? inf))
          (test-equal (onie-info-product-name inf) "prod1")
          (test-equal (onie-info-part-number inf) "part-num1")
	  (test-equal (onie-info-serial-number inf) "serial1")
	  (test-equal (onie-info-mac-base inf) #vu8(11 22 33 44 55 66))
          (test-equal (onie-info-manufacture-date inf) "08/16/2024 00:00:00")
          (test-equal (onie-info-device-version inf) 1)
          (test-equal (onie-info-label-revision inf) "R01")
          (test-equal (onie-info-platform-name inf) "arm64-accton_xxx-r0")
          (test-equal (onie-info-onie-version inf) "1.1.1")
          (test-equal (onie-info-num-macs inf) 63)
          (test-equal (onie-info-manufacturer inf) "SomeSwitchMfg")
          (test-equal (onie-info-country-code inf) "UA")
          (test-equal (onie-info-vendor inf) "SomeVendor")
          (test-equal (onie-info-diag-version inf) "V1.1.3.243")
          (test-equal (onie-info-service-tag inf) "3001995")
          (test-equal (onie-info-vendor-extension inf) #vu8(1 2 3 4 5 6))
	  )))))
(test-end)

(exit (if (zero? (test-runner-fail-count (test-runner-get))) 0 1))
